@@ -2,7 +2,10 @@ use aws_sdk_ec2 as ec2;
 
 pub(crate) trait Show {
     fn id(&self) -> String;
-    fn id_and_name(&self) -> String;
+    fn tags(&self) -> &Option<Vec<ec2::model::Tag>>;
+    fn id_and_name(&self) -> String {
+        format!("{}{}", self.id(), format_name(self.tags()))
+    }
 }
 
 impl Show for Option<&ec2::Region> {
@@ -10,6 +13,10 @@ impl Show for Option<&ec2::Region> {
         self.map(ToString::to_string).unwrap_or_default()
     }
 
+    fn tags(&self) -> &Option<Vec<ec2::model::Tag>> {
+        &None
+    }
+
     fn id_and_name(&self) -> String {
         self.id()
     }
@@ -20,11 +27,8 @@ impl Show for ec2::model::Vpc {
         self.vpc_id.clone().unwrap_or_default()
     }
 
-    fn id_and_name(&self) -> String {
-        let name = get_name_tag_if_any(&self.tags)
-            .map(|name| format!(" ({})", name))
-            .unwrap_or_default();
-        format!("{}{}", self.id(), name)
+    fn tags(&self) -> &Option<Vec<ec2::model::Tag>> {
+        &self.tags
     }
 }
 
@@ -33,11 +37,8 @@ impl Show for ec2::model::InternetGateway {
         self.internet_gateway_id.clone().unwrap_or_default()
     }
 
-    fn id_and_name(&self) -> String {
-        let name = get_name_tag_if_any(&self.tags)
-            .map(|name| format!(" ({})", name))
-            .unwrap_or_default();
-        format!("{}{}", self.id(), name)
+    fn tags(&self) -> &Option<Vec<ec2::model::Tag>> {
+        &self.tags
     }
 }
 
@@ -46,11 +47,8 @@ impl Show for ec2::model::Subnet {
         self.subnet_id.clone().unwrap_or_default()
     }
 
-    fn id_and_name(&self) -> String {
-        let name = get_name_tag_if_any(&self.tags)
-            .map(|name| format!(" ({})", name))
-            .unwrap_or_default();
-        format!("{}{}", self.id(), name)
+    fn tags(&self) -> &Option<Vec<ec2::model::Tag>> {
+        &self.tags
     }
 }
 
@@ -59,11 +57,8 @@ impl Show for ec2::model::RouteTable {
         self.route_table_id.clone().unwrap_or_default()
     }
 
-    fn id_and_name(&self) -> String {
-        let name = get_name_tag_if_any(&self.tags)
-            .map(|name| format!(" ({})", name))
-            .unwrap_or_default();
-        format!("{}{}", self.id(), name)
+    fn tags(&self) -> &Option<Vec<ec2::model::Tag>> {
+        &self.tags
     }
 }
 
@@ -72,14 +67,47 @@ impl Show for ec2::model::Instance {
         self.instance_id.clone().unwrap_or_default()
     }
 
-    fn id_and_name(&self) -> String {
-        let name = get_name_tag_if_any(&self.tags)
-            .map(|name| format!(" ({})", name))
-            .unwrap_or_default();
-        format!("{}{}", self.id(), name)
+    fn tags(&self) -> &Option<Vec<ec2::model::Tag>> {
+        &self.tags
     }
 }
 
+impl Show for ec2::model::NetworkAcl {
+    fn id(&self) -> String {
+        self.network_acl_id.clone().unwrap_or_default()
+    }
+
+    fn tags(&self) -> &Option<Vec<ec2::model::Tag>> {
+        &self.tags
+    }
+}
+
+impl Show for ec2::model::VpcPeeringConnection {
+    fn id(&self) -> String {
+        self.vpc_peering_connection_id.clone().unwrap_or_default()
+    }
+
+    fn tags(&self) -> &Option<Vec<ec2::model::Tag>> {
+        &self.tags
+    }
+}
+
+impl Show for ec2::model::VpcEndpoint {
+    fn id(&self) -> String {
+        self.vpc_endpoint_id.clone().unwrap_or_default()
+    }
+
+    fn tags(&self) -> &Option<Vec<ec2::model::Tag>> {
+        &self.tags
+    }
+}
+
+fn format_name(tags: &Option<Vec<ec2::model::Tag>>) -> String {
+    get_name_tag_if_any(tags)
+        .map(|name| format!(" ({})", name))
+        .unwrap_or_default()
+}
+
 fn get_name_tag_if_any(tags: &Option<Vec<ec2::model::Tag>>) -> Option<String> {
     tags.as_deref()
         .unwrap_or_default()
